<?php

class Sitereview_IndexController extends Seaocore_Controller_Action_Standard {

    protected $_navigation;
    protected $_listingType;

    /*
     * Common action which call before every action of this controller.
     */

    public function init() {
        // Set listing type id and object
        $listingtype_id = $this->_getParam('listingtype_id', null);
        if ($listingtype_id != -1 && !empty($listingtype_id)) {
            Engine_Api::_()->sitereview()->setListingTypeInRegistry($listingtype_id);
            $this->_listingType = Zend_Registry::get('listingtypeArray' . $listingtype_id);
            Zend_Registry::isRegistered('sitereviewGetListingType') ? $sitereviewGetListingType = true : $this->_setParam('listing_id', 0);

            // Authorization check
            if ($this->_getParam('action', null) != 'categories')
                if (!$this->_helper->requireAuth()->setAuthParams('sitereview_listing', null, "view_listtype_$listingtype_id")->isValid())
                    return;
        }

        if (Engine_Api::_()->getDbtable('modules', 'core')->isModuleEnabled('sitereviewpaidlisting')) {
            // For update expiration
            if ((Engine_Api::_()->getApi('settings', 'core')->getSetting('sitereviewpaidlisting.task.updateexpiredlistings') + 900) <= time())
                Engine_Api::_()->sitereviewpaidlisting()->updateExpiredListings($listingtype_id);
        }
    }

    /*
     * None user specific method. Call using the routes
     */

    public function indexAction() {
        // Get page object
        $listingtype_id = $this->_listingType->listingtype_id;
        $pageTable = Engine_Api::_()->getDbtable('pages', 'core');
        $pageSelect = $pageTable->select()->where('name = ?', "sitereview_index_index_listtype_$listingtype_id");
        $pageObject = $pageTable->fetchRow($pageSelect);
        $listingTypeTable = Engine_Api::_()->getDbTable('listingtypes', 'sitereview');

        // Set meta params
        $params = array();
        $listing_type_title = '';
        if (empty($pageObject->title)) {
            $listing_type_title = ucfirst($this->_listingType->title_plural);
            $params['default_title'] = $title = Zend_Registry::get('Zend_Translate')->_('Browse ' . $listing_type_title);
        }
        $description = '';
        if (empty($pageObject->description)) {
            $listing_type_singular = strtolower($listingTypeTable->getListingTypeColumn($listingtype_id, 'title_singular'));
            $params['description'] = $description = Zend_Registry::get('Zend_Translate')->_('This is the ' . $listing_type_singular . ' browse page.');
        }

        // Get listing category table
        $tableCategory = Engine_Api::_()->getDbTable('categories', 'sitereview');
        $request = Zend_Controller_Front::getInstance()->getRequest();
        $browseCategories = Zend_Registry::isRegistered('sitereviewBrowseCategories') ? Zend_Registry::get('sitereviewBrowseCategories') : null;

        $category_id = $request->getParam('category_id', null);
        if (empty($browseCategories)) {
            $this->view->categoryError = $this->view->translate("There are no categories found for this page.");
            return;
        }

        if (!empty($category_id)) {
            if ($listing_type_title)
                $params['listing_type_title'] = $title = $listing_type_title;

            $meta_title = $tableCategory->getCategory($category_id)->meta_title;
            if (empty($meta_title)) {
                if (Engine_Api::_()->getItem('sitereview_category', $category_id))
                    $params['categoryname'] = Engine_Api::_()->getItem('sitereview_category', $category_id)->getCategorySlug();
            } else {
                $params['categoryname'] = $meta_title;
            }

            $meta_description = $tableCategory->getCategory($category_id)->meta_description;
            if (!empty($meta_description))
                $params['description'] = $meta_description;

            $meta_keywords = $tableCategory->getCategory($category_id)->meta_keywords;
            if (empty($meta_keywords))
                $params['categoryname_keywords'] = (Engine_Api::_()->getItem('sitereview_category', $category_id)) ? Engine_Api::_()->getItem('sitereview_category', $category_id)->getCategorySlug() : "";
            else
                $params['categoryname_keywords'] = $meta_keywords;

            $subcategory_id = $request->getParam('subcategory_id', null);

            if (!empty($subcategory_id)) {
                $meta_title = $tableCategory->getCategory($subcategory_id)->meta_title;
                if (empty($meta_title))
                    $params['subcategoryname'] = Engine_Api::_()->getItem('sitereview_category', $subcategory_id)->getCategorySlug();
                else
                    $params['subcategoryname'] = $meta_title;

                $meta_description = $tableCategory->getCategory($subcategory_id)->meta_description;
                if (!empty($meta_description))
                    $params['description'] = $meta_description;

                $meta_keywords = $tableCategory->getCategory($subcategory_id)->meta_keywords;
                if (empty($meta_keywords))
                    $params['subcategoryname_keywords'] = Engine_Api::_()->getItem('sitereview_category', $subcategory_id)->getCategorySlug();
                else
                    $params['subcategoryname_keywords'] = $meta_keywords;

                $subsubcategory_id = $request->getParam('subsubcategory_id', null);

                if (!empty($subsubcategory_id)) {
                    $meta_title = $tableCategory->getCategory($subsubcategory_id)->meta_title;
                    if (empty($meta_title))
                        $params['subsubcategoryname'] = Engine_Api::_()->getItem('sitereview_category', $subsubcategory_id)->getCategorySlug();
                    else
                        $params['subsubcategoryname'] = $meta_title;

                    $meta_description = $tableCategory->getCategory($subsubcategory_id)->meta_description;
                    if (!empty($meta_description))
                        $params['description'] = $meta_description;

                    $meta_keywords = $tableCategory->getCategory($subsubcategory_id)->meta_keywords;
                    if (empty($meta_keywords))
                        $params['subsubcategoryname_keywords'] = Engine_Api::_()->getItem('sitereview_category', $subsubcategory_id)->getCategorySlug();
                    else
                        $params['subsubcategoryname_keywords'] = $meta_keywords;
                }
            }
        }

        // Set meta title
        Engine_Api::_()->sitereview()->setMetaTitles($params);
        Engine_Api::_()->sitereview()->setMetaDescriptionsBrowse($params);

        // Get location
        if (isset($_GET['location']) && !empty($_GET['location']))
            $params['location'] = $_GET['location'];

        // Get tag
        if (isset($_GET['tag']) && !empty($_GET['tag']))
            $params['tag'] = $_GET['tag'];

        // Get search
        if (isset($_GET['search']) && !empty($_GET['search']))
            $params['search'] = $_GET['search'];

        $params['listing_type_title'] = $listingTypeTable->getListingTypeColumn($listingtype_id, 'title_plural');
        $params['page'] = 'browse';

        $searchForm = new Sitereview_Form_Search(array('type' => 'sitereview_listing', 'listingTypeId' => $listingtype_id));
        Zend_Registry::set('Sitereview_Form_Search', $searchForm);

        Engine_Api::_()->sitereview()->setMetaKeywords($params);

        $this->_helper->content
                ->setContentName("sitereview_index_index_listtype_$listingtype_id")
                ->setNoRender()
                ->setEnabled();
    }

}
